Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartin Poirier <theeth@yahoo.com>2009-10-17 18:45:49 +0400
committerMartin Poirier <theeth@yahoo.com>2009-10-17 18:45:49 +0400
commit9d98b489256ef3783a5a8a1dc40b837dbc5b064d (patch)
tree597ca85044d0e2db902caa9458bd979e15e55904 /source/blender/editors/mesh/mesh_ops.c
parent91d89c1ff7c215744e46957a1e7cc40adb7ac066 (diff)
Temporary remap extrude to Ctrl+Alt+Click, to avoid conflict with transform.
Diffstat (limited to 'source/blender/editors/mesh/mesh_ops.c')
-rw-r--r--source/blender/editors/mesh/mesh_ops.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/source/blender/editors/mesh/mesh_ops.c b/source/blender/editors/mesh/mesh_ops.c
index df80b74f19f..dc22e023856 100644
--- a/source/blender/editors/mesh/mesh_ops.c
+++ b/source/blender/editors/mesh/mesh_ops.c
@@ -267,8 +267,10 @@ void ED_keymap_mesh(wmKeyConfig *keyconf)
RNA_string_set(kmi->ptr, "name", "INFO_MT_mesh_add");
WM_keymap_add_item(keymap, "MESH_OT_separate", PKEY, KM_PRESS, 0, 0);
- /* use KM_RELEASE because same key is used for tweaks */
- WM_keymap_add_item(keymap, "MESH_OT_dupli_extrude_cursor", LEFTMOUSE, KM_RELEASE, KM_CTRL, 0);
+ /* use KM_RELEASE because same key is used for tweaks
+ * TEMPORARY REMAP TO ALT+CTRL TO AVOID CONFLICT
+ * */
+ WM_keymap_add_item(keymap, "MESH_OT_dupli_extrude_cursor", LEFTMOUSE, KM_RELEASE, KM_CTRL|KM_ALT, 0);
WM_keymap_add_item(keymap, "MESH_OT_delete", XKEY, KM_PRESS, 0, 0);
WM_keymap_add_item(keymap, "MESH_OT_delete", DELKEY, KM_PRESS, 0, 0);